summaryrefslogtreecommitdiffstats
path: root/tdeui/qxembed.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
commitd4e11a5f488204ab8886e167c7c4af1e6e16ab58 (patch)
tree367a2caa6169a869cfbf6395dffe2d28e0f72654 /tdeui/qxembed.cpp
parent2c4de80e1e29b261fe8770483f97b2d702e4bd08 (diff)
downloadtdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.tar.gz
tdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.zip
Use non-tq sizeHint functions to fix bindings
Diffstat (limited to 'tdeui/qxembed.cpp')
-rw-r--r--tdeui/qxembed.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/qxembed.cpp b/tdeui/qxembed.cpp
index 769625a8c..e0ce2166b 100644
--- a/tdeui/qxembed.cpp
+++ b/tdeui/qxembed.cpp
@@ -1332,7 +1332,7 @@ void QXEmbed::embedClientIntoWindow(TQWidget* client, WId window)
// L2500: Specifies that this widget can use additional space,
// and that it can survive on less than tqsizeHint().
TQSizePolicy QXEmbed::sizePolicy() const
{
return TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
@@ -1340,13 +1340,13 @@ TQSizePolicy QXEmbed::sizePolicy() const
// L2520: Returns a size sufficient for the embedded window
-TQSize QXEmbed::tqsizeHint() const
+TQSize QXEmbed::sizeHint() const
{
- return tqminimumSizeHint();
+ return minimumSizeHint();
}
// L2550: Returns the minimum size specified by the embedded window.
-TQSize QXEmbed::tqminimumSizeHint() const
+TQSize QXEmbed::minimumSizeHint() const
{
int minw = 0;
int minh = 0;
@@ -1332,7 +1332,7 @@ void QXEmbed::embedClientIntoWindow(TQWidget* client, WId window)
// L2500: Specifies that this widget can use additional space,
-// and that it can survive on less than tqsizeHint().
+// and that it can survive on less than sizeHint().
TQSizePolicy QXEmbed::sizePolicy() const
{